@@ -30,9 +30,9 @@ import numpy
 from collections import defaultdict
 # mine
 from HandwrittenData import HandwrittenData  # Needed because of pickle
-import preprocessing  # Needed because of pickle
-import features
-import data_multiplication
+from . import preprocessing  # Needed because of pickle
+from . import features
+from . import data_multiplication
 
 
 def main(feature_folder, create_learning_curve=False):
